# Convex Sync Types

Internal sync types for the Convex protocol required for building a subscription
client.

For a fully built client using tokio, see

https://crates.io/crates/convex/

https://github.com/get-convex/convex-rs
